#ifndef GW_GWAEI_INCLUDED
#define GW_GWAEI_INCLUDED
 
#include <libwaei/libwaei.h>

#include <gtk/gtk.h>

#include <gwaei/dictionarylist.h>
#include <gwaei/history.h>

#include <gwaei/application.h>


#include <gwaei/texttagtable.h>
#include <gwaei/spellcheck.h>
#include <gwaei/printing.h>

#include <gwaei/window.h>
#include <gwaei/searchwindow.h>
#include <gwaei/radicalswindow.h>
#include <gwaei/kanjipadwindow.h>
#include <gwaei/settingswindow.h>
#include <gwaei/dictionaryinstallwindow.h>
#include <gwaei/installprogresswindow.h>
#include <gwaei/vocabularywindow.h>
#include <gwaei/addvocabularywindow.h>
#include <gwaei/flashcardwindow.h>


#endif
